@@ -44,6 +44,10 @@ def stop_service(bin_path, daemon_script_name):
 def start_mft():
   print("Setting up MFT Services")
 
+  mft_dir = os.path.join(os.path.expanduser('~'), ".mft")
+  if not os.path.exists(mft_dir):
+    os.makedirs(mft_dir)
+
   path = os.path.join(os.path.expanduser('~'), ".mft/consul")
   if not os.path.exists(path):
     consul_macos_url = "https://releases.hashicorp.com/consul/1.7.1/consul_1.7.1_darwin_amd64.zip"
